@@ -3,7 +3,7 @@
                              -------------------
     begin                : Sun Aug 29 2004
     copyright            : (C) 2004, 2009, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
