@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Sep 13 2005
     copyright            : (C) 2005, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -57,7 +57,7 @@ ShowEditTextFileAgent::ShowEditTextFileAgent (RBackendRequest *request, const QS
 
 	dialog->setButtonText (KDialog::Ok, i18n ("Done"));
 
-	connect (dialog, SIGNAL (finished ()), this, SLOT (deleteLater ()));
+	connect (dialog, SIGNAL (finished()), this, SLOT (deleteLater()));
 
 	// do it
 	dialog->show ();
