@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Aug 31 2004
     copyright            : (C) 2004, 2007, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -71,7 +71,11 @@ private:
 	int num_watched_objects;
 };
 
-/** An item model for the RObjectList . Technically this is the base class for RKModificationTracker. The two could be merged, fully, but this way, it's a little easier to see what belongs where, logically. */
+/** An item model for the RObjectList . Technically this is the base class for RKModificationTracker. The two could be merged, fully, but this way, it's a little easier to see what belongs where, logically.
+
+ The object item model is mostly organized exactly like the tree of R objects rooted at RObjectList::getObjectList(). One small difference is that
+ in the item model .GlobalEnv is one child of the root, and the other loaded environments are contained in a sibling to this.
+*/
 class RKObjectListModel : public QAbstractItemModel {
 public:
 	enum Column {
@@ -117,8 +121,7 @@ This class takes care of propagating object-modifications to all editors/variabl
 */
 class RKModificationTracker : public RKObjectListModel {
 public:
-	RKModificationTracker (QObject *parent);
-
+	explicit RKModificationTracker (QObject *parent);
 	~RKModificationTracker ();
 	
 /** the given object should be removed (either it was removed in the R-workspace, or the user requests removal of the object in an editor or the RObjectList). First, if the object is being edited somewhere, the user will get a chance to object to the removal. If the user does not object, the RKModificationTracker will remove the object and notify all interested listeners that the object really was removed. When calling from the RObjectList, you will likely set removed_in_workspace to true, to signal that the object-data is already gone in the workspace. */
