@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Oct 17 2005
     copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -102,7 +102,7 @@ namespace RKCommonFunctions {
 	}
 
 	QString getCurrentSymbol (const QString &context_line, int cursor_pos, bool strict) {
-		if (context_line.isEmpty ()) return (QString::null);
+		if (context_line.isEmpty ()) return (QString ());
 
 		int current_word_start;
 		int current_word_end;
