@@ -2,7 +2,7 @@
                           rkstandardactions  -  description
                              -------------------
     begin                : Sun Nov 18 2007
-    copyright            : (C) 2007-2013 by Thomas Friedrichsmeier
+    copyright            : (C) 2007-2016 by Thomas Friedrichsmeier
     email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
@@ -24,6 +24,8 @@
 #include "rkstandardicons.h"
 #include "rkspecialactions.h"
 #include "../windows/rkmdiwindow.h"
+#include "../windows/rkcommandeditorwindow.h"
+#include "../windows/rkhelpsearchwindow.h"
 
 #include "../debug.h"
 
@@ -71,11 +73,67 @@ KAction* RKStandardActions::runAll (RKMDIWindow *window, const QObject *receiver
 	return ret;
 }
 
-KAction* RKStandardActions::functionHelp (RKMDIWindow *window, const QObject *receiver, const char *member) {
+class RKSearchRHelpAction : public KAction {
+	Q_OBJECT
+public:
+	RKSearchRHelpAction (QObject *parent, RKScriptContextProvider *context_provider) : KAction (parent) {
+		RK_TRACE (MISC);
+		provider = context_provider;
+		setText (i18n ("&Function reference"));
+		setShortcut (Qt::Key_F2);
+		connect (this, SIGNAL (triggered(bool)), this, SLOT (doSearch()));
+	};
+public slots:
+	void doSearch () {
+		RK_TRACE (MISC);
+		QString symbol, package;
+		provider->currentHelpContext (&symbol, &package);
+		RKHelpSearchWindow::mainHelpSearch ()->getFunctionHelp (symbol, package);
+	};
+private:
+	RKScriptContextProvider *provider;
+};
+
+KAction* RKStandardActions::functionHelp (RKMDIWindow *window, RKScriptContextProvider *context_provider) {
 	RK_TRACE (MISC);
 
-	KAction* ret = window->standardActionCollection ()->addAction ("function_reference", receiver, member);
-	ret->setText (i18n ("&Function reference"));
-	ret->setShortcut (Qt::Key_F2);
+	KAction* ret = new RKSearchRHelpAction (window, context_provider);
+	window->standardActionCollection ()->addAction ("function_reference", ret);
 	return ret;
 }
+
+#include <kurifilter.h>
+#include <ktoolinvocation.h>
+
+class RKSearchOnlineHelpAction : public KAction {
+	Q_OBJECT
+public:
+	RKSearchOnlineHelpAction (QObject *parent, RKScriptContextProvider *context_provider) : KAction (parent) {
+		RK_TRACE (MISC);
+		provider = context_provider;
+		setText (i18n ("Search Online"));
+		connect (this, SIGNAL (triggered(bool)), this, SLOT (doSearch()));
+	};
+public slots:
+	void doSearch () {
+		RK_TRACE (MISC);
+		QString symbol, package;
+		provider->currentHelpContext (&symbol, &package);
+		KUriFilterData data (symbol + " " + package + " R");
+		KUriFilter::self ()->filterSearchUri (data, KUriFilter::NormalTextFilter);
+		KToolInvocation::invokeBrowser (data.uri ().url ());
+	};
+private:
+	RKScriptContextProvider *provider;
+};
+
+KAction* RKStandardActions::onlineHelp (RKMDIWindow *window, RKScriptContextProvider *context_provider) {
+	RK_TRACE (MISC);
+
+	// KF5 TODO: Add / replace with submenu to select search provider -> KUriFilterSearchProviderActions
+	KAction* ret = new RKSearchOnlineHelpAction (window, context_provider);
+	window->standardActionCollection ()->addAction ("search_online", ret);
+	return ret;
+}
+
+#include "rkstandardactions_moc.cpp"
