@@ -2,7 +2,7 @@
                           rkstandardactions  -  description
                              -------------------
     begin                : Sun Nov 18 2007
-    copyright            : (C) 2007-2013 by Thomas Friedrichsmeier
+    copyright            : (C) 2007-2016 by Thomas Friedrichsmeier
     email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
@@ -22,6 +22,7 @@ class KAction;
 class QString;
 class QObject;
 class RKMDIWindow;
+class RKScriptContextProvider;
 
 /** This namespace provides functions to generate some standard actions, i.e. actions which are needed at more than one place.
 
@@ -35,7 +36,10 @@ namespace RKStandardActions {
 	KAction* runCurrent (RKMDIWindow *window, const QObject *receiver=0, const char *member=0, bool current_or_line=false);
 	KAction* runAll (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
 
-	KAction* functionHelp (RKMDIWindow *window, const QObject *receiver=0, const char *member=0);
+	KAction* functionHelp (RKMDIWindow *window, RKScriptContextProvider *context_provider);
+/** Search for current symbol / selection, online. Note that you will not have to connect this action to any slot to work. It does everything by itself.
+ *  It will query the given context_provider for context. */
+	KAction* onlineHelp (RKMDIWindow *window, RKScriptContextProvider *context_provider);
 };
 
 #endif
