@@ -2,8 +2,8 @@
                           rkcomponent  -  description
                              -------------------
     begin                : Tue Dec 13 2005
-    copyright            : (C) 2005, 2006, 2009, 2010, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2006, 2009, 2010, 2011, 2012, 2013, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,12 +31,12 @@ RKComponentBase* RKComponentBase::lookupComponent (const QString &identifier, QS
 	if (identifier.isEmpty ()) return this;
 	RK_DEBUG (PLUGIN, DL_DEBUG, "looking up '%s'", identifier.toLatin1 ().data ());
 
-	RKComponentBase *child = child_map.value (identifier.section (".", 0, 0));
+	RKComponentBase *child = child_map.value (identifier.section ('.', 0, 0));
 	if (!child) {	// if we do not have such a child, return this (and set remainder)
 		*remainder = identifier;
 		return this;
 	} else {	// else do recursive lookup
-		return child->lookupComponent (identifier.section (".", 1), remainder);
+		return child->lookupComponent (identifier.section ('.', 1), remainder);
 	}
 }
 
@@ -109,7 +109,7 @@ QString RKComponentBase::valueMapToString (const PropertyValueMap &map) {
 	QString out;
 	for (PropertyValueMap::const_iterator it = map.constBegin (); it != map.constEnd (); ++it) {
 		if (!out.isEmpty ()) out.append ("\n");
-		out.append (RKCommonFunctions::escape (it.key () + "=" + it.value ()));
+		out.append (RKCommonFunctions::escape (it.key () + '=' + it.value ()));
 	}
 	return out;
 }
@@ -199,10 +199,26 @@ QVariant RKComponentBase::fetchValue (const QString &id, const int hint) {
 	} else {
 		QString mod;
 		RKComponentBase *prop = lookupComponent (id, &mod);
+		if (hint == UiLabelPair) {
+			QStringList ret;
+			if (prop->isComponent ()) {
+				ret = static_cast<const RKComponent*> (prop)->getUiLabelPair ();
+				if (ret.isEmpty ()) {
+					RK_DEBUG (PLUGIN, DL_WARNING, "Component id %s does not support getting ui labels.", qPrintable (id));
+				}
+				RK_ASSERT (!(ret.size () % 2));
+			} else {
+				RK_DEBUG (PLUGIN, DL_WARNING, "Getting ui labels is not supported for properties, only for components. Failed id was: %s", qPrintable (id));
+			}
+			if (ret.isEmpty ()) {
+				ret << "-" << "-";
+			}
+			return QVariant (ret);
+		}
 		QVariant val = prop->value (mod);
 		if (hint == BooleanValue) {
 			bool ok;
-			return (RKComponentPropertyBool::variantToBool (val, &ok));
+			val = RKComponentPropertyBool::variantToBool (val, &ok);
 			if (!ok) RK_DEBUG (PLUGIN, DL_WARNING, "Could not convert value of %s to boolean", qPrintable (id));
 		} else {
 			if (hint == StringlistValue) {
@@ -212,8 +228,8 @@ QVariant RKComponentBase::fetchValue (const QString &id, const int hint) {
 			} else {
 				RK_ASSERT (false);
 			}
-			return (val);
 		}
+		return (val);
 	}
 }
 
@@ -263,15 +279,15 @@ void RKComponent::createDefaultProperties () {
 	addChild ("enabled", enabledness_property = new RKComponentPropertyBool (this, false));
 	enabledness_property->setBoolValue (true);
 	enabledness_property->setInternal (true);
-	connect (enabledness_property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (propertyValueChanged (RKComponentPropertyBase *)));
+	connect (enabledness_property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (propertyValueChanged(RKComponentPropertyBase*)));
 	addChild ("visible", visibility_property = new RKComponentPropertyBool (this, false));
 	visibility_property->setBoolValue (true);
 	visibility_property->setInternal (true);
-	connect (visibility_property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (propertyValueChanged (RKComponentPropertyBase *)));
+	connect (visibility_property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (propertyValueChanged(RKComponentPropertyBase*)));
 	addChild ("required", requiredness_property = new RKComponentPropertyBool (this, false));
 	requiredness_property->setBoolValue (true);
 	requiredness_property->setInternal (true);
-	connect (requiredness_property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (propertyValueChanged (RKComponentPropertyBase *)));
+	connect (requiredness_property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (propertyValueChanged(RKComponentPropertyBase*)));
 }
 
 RKComponent::~RKComponent () {
@@ -369,10 +385,10 @@ void RKComponent::changed () {
 	emit (componentChanged (this));
 }
 
-RKStandardComponent *RKComponent::standardComponent (QString *id_adjust) {
+RKStandardComponent *RKComponent::standardComponent (QString *id_adjust) const {
 	RK_TRACE (PLUGIN);
 
-	RKComponent *p = this;
+	RKComponent *p = const_cast<RKComponent*> (this);
 	while (p) {
 		if (p->type () == RKComponent::ComponentStandard) return static_cast<RKStandardComponent*> (p);
 		if (id_adjust) id_adjust->prepend (p->getIdInParent () + '.');
@@ -393,6 +409,13 @@ RKStandardComponent* RKComponent::topmostStandardComponent () {
 	return 0;
 }
 
+XMLHelper* RKComponent::xmlHelper () const {
+	RK_TRACE (PLUGIN);
+
+	RKStandardComponent *sc = standardComponent ();
+	return sc->getXmlHelper ();
+}
+
 void RKComponent::removeFromParent () {
 	RK_TRACE (PLUGIN);
 
@@ -413,4 +436,19 @@ QString RKComponent::getIdInParent () const {
 	return (parentComponent ()->child_map.key (const_cast<RKComponent*> (this)));
 }
 
+// static
+QString RKComponent::stripAccelerators (const QString& in) {
+	QString ret;
+	ret.reserve (in.size ());
+	for (int i = 0; i < in.size (); ++i) {
+		QChar c = in[i];
+		if (c == QLatin1Char ('&')) {
+			if (++i < in.size ()) ret.append (in[i]);
+		} else {
+			ret.append (c);
+		}
+	}
+	return ret;
+}
+
 #include "rkcomponent.moc"
