@@ -2,8 +2,8 @@
                           rkcomponentmap.h  -  description
                              -------------------
     begin                : Thu May 12 2005
-    copyright            : (C) 2005-2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005-2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,24 +19,34 @@
 #define RKCOMPONENTMAP_H
 
 #include <qstring.h>
+#include <QSet>
 
 #include "rkcomponentmeta.h"
 
+class RKMessageCatalog;
+class XMLHelper;
 /** very simple helper class to keep track of .pluginmap files */
 class RKPluginMapFile {
 public:
-	RKPluginMapFile (const QString &basedir) { RKPluginMapFile::basedir = basedir; };
-	~RKPluginMapFile () {};
+	RKPluginMapFile (const QString &filename, const QString &basedir, const RKMessageCatalog *_catalog) { RKPluginMapFile::filename = filename; RKPluginMapFile::basedir = basedir; catalog = _catalog; about = 0; };
+	~RKPluginMapFile () { delete about; };
 
-	QString getBaseDir () { return basedir; };
-	QString makeFileName (const QString &filename);
-	QList<RKComponentDependency> getDependencies () { return dependencies; };
-	static QString parseId (const QDomElement &e);
+	QString getBaseDir () const { return basedir; };
+	QString getFileName () const { return filename; };
+	QString makeFileName (const QString &filename) const;
+	QList<RKComponentDependency> getDependencies () const { return dependencies; };
+	static QString parseId (const QDomElement &e, XMLHelper &xml);
+	const RKMessageCatalog *messageCatalog () const { return catalog; };
+	/** Get the about data for this pluginmap. */
+	RKComponentAboutData getAboutData ();
 private:
 friend class RKComponentMap;
 	QString basedir;
+	QString filename;
 	QString id;
 	QList<RKComponentDependency> dependencies;
+	const RKMessageCatalog *catalog;
+	RKComponentAboutData *about;
 };
 
 /** enum of different types of RKComponent */
@@ -59,17 +69,14 @@ class KActionCollection;
 
 @author Thomas Friedrichsmeier
 */
-class RKComponentHandle : public QObject {
-	Q_OBJECT
+class RKComponentHandle {
 public:
-	RKComponentHandle (RKPluginMapFile *pluginmap, const QString &rel_filename, const QString &label, RKComponentType type);
+	RKComponentHandle (RKPluginMapFile *pluginmap, const QString &rel_filename, const QString &label);
 	virtual ~RKComponentHandle ();
 
-	QString getFilename () { return plugin_map->makeFileName (filename); };
-	QString getLabel () { return label; };
-	RKComponentType getType () { return type; };
-	bool isPlugin ();
-	QString getPluginmapFilename ();
+	QString getFilename () const { return plugin_map->makeFileName (filename); };
+	QString getLabel () const { return label; };
+	QString getPluginmapFilename () const;
 
 	RKStandardComponent *invoke (RKComponent *parent_component, QWidget *parent_widget);
 
@@ -84,9 +91,10 @@ public:
 	void setAccessible (bool accessible) { is_accessible = accessible; };
 /** Returns whether this component is accessible from the menu, somewhere (else it might be in a context) */
 	bool isAccessible () const { return is_accessible; };
-public slots:
-/** Slot called, when the menu-item for this component is selected. Responsible for creating the GUI. */
-	void activated ();
+	const RKMessageCatalog *messageCatalog () const { return plugin_map->messageCatalog (); };
+/** Returns the about data for this component (likely that of the containing pluginmap). Note that in contrast to RKPluginMapFile::getAboutData (), the parsed
+ *  about data is not cached, as access to this data should be infrequent. */
+	RKComponentAboutData getAboutData ();
 protected:
 /** The plugin map where this component was declared */
 	RKPluginMapFile *plugin_map;
@@ -98,57 +106,89 @@ private:
 	bool is_accessible;
 };
 
-#include <qmap.h>
+#include <QMultiMap>
 #include <QDomDocument>
 
 #include <kxmlguiclient.h>
 
 class QDomElement;
+class XMLHelper;
+class RKContextHandler;
 
 /** This class keeps a QDomDocument that is a represenation of the GUI using KDEs XML-GUI format (a ui.rc). Use createMenus () to have it parse the menu descriptions from a .pluginmap file. It will adjust the XML description accordingly. When done, you can use to generated gui_xml to set it as the xmlGUIBuildDocument of a KXMLGUIClient. 
 
-This class represents the common functionality between RKComponentMap and RKContextMap.
+One instance of this class is generally around, persistently: The RKComonentMap (with context "global"). Further instances are around one for each context.
 
 @author Thomas Friedrichsmeier
 */
 class RKComponentGUIXML {
+public:
+	class Entry {
+	public:
+		Entry () { is_menu = false; }
+		QString label;
+		QString id;
+		bool is_menu;
+	};
+	class Group {
+	public:
+		~Group ();
+		QString id;
+		bool separated;
+		QList<Entry*> entries;
+	};
+	class Menu : public Entry {
+	public:
+		Menu () { is_menu = true; }
+		~Menu () { clear (); }
+		void clear ();
+		QList<Group*> groups;
+		QSet<QString> components;
+	} toplevel_menu;
+/** build XMLGUI menus
+@param hierarchy_description the QDomElement containing the description for the new menu hierarchy
+@returns number of plugins/menu-entries added successfully */
+	int createMenus (XMLHelper &xml, const QDomElement& hierarchy_description, const QString& cnamespace);
+	void finalize ();
+
+/** Create a context handler for this context. */
+	RKContextHandler *makeContextHandler (QObject *parent, bool create_actions=true);
+	QStringList components () { return component_menus.keys (); };
 protected:
-	RKComponentGUIXML ();
+	RKComponentGUIXML (const QString &context_id);
 	virtual ~RKComponentGUIXML ();
 
 /** reset the xml file */
 	void clearGUIDescription ();
 
-/** build XMLGUI menus
-@param parent the parent menu (or tag) (in the KXMLGUI)
-@param hierarchy_description the QDomElement containing the description for the new menu hierarchy
-@returns number of plugins/menu-entries added successfully */
-	int createMenus (QDomElement& parent, const QDomElement& hierarchy_description, const QString& cnamespace);
-
-/** recurse into a lower menu-level 
-@param parent the parent menu (in the KXMLGUI)
-@param description the QDomElement containing the description for the new submenu
-@returns number of plugins/menu-entries added successfully */
-	int addSubMenu (QDomElement& parent, const QDomElement& description, const QString& cnamespace);
-
-/** helper function: Find a specified element, and return it. If the element could not be found, it is created instead. The first three parameters are used as search parameters (all have to match). The additional two parameters only take effect, if a new element is created.
-@param parent the QDomElement whose children to search through
-@param tagname the tagname to look for
-@param name value of the "name"-attribute to look for
-@param label the label to assign to the new element (if no existing match could be found)
-@param index the index position where to insert the new element in the list of children (if no existing match could be found). -1 means insert at the end of the list. */
-	QDomElement findOrCreateElement (QDomElement& parent, const QString& tagname, const QString& name, const QString& label, int index);
-
 /** an entry was added to the menu(s) somewhere. Reimplement, if you want to e.g. create a KAction for this */
 	virtual void addedEntry (const QString & /* id */, RKComponentHandle * /* handle */) {};
 
 /** The generated XML GUI description in KDEs ui.rc format */
 	QDomDocument gui_xml;
+friend class RKComponentMap;
+	QMap<QString, QString> component_menus;
+
+/** Add a component override, e.g. hiding component "t_test" in context "global". Overrides are persistent per session. */
+	static void addOverride (const QString &id, const QString &context, bool visible);
+/** Clear component overrides (see addOverride()). */
+	static void clearOverrides ();
+private:
+	int addEntries (RKComponentGUIXML::Menu *menu, XMLHelper &xml, const QDomElement description, const QString& cnamespace);
+	void menuItemsToXml (const RKComponentGUIXML::Menu *menu, QDomElement &xml);
+	void resolveComponentLabelsAndSortMenu (Menu *menu, const QString &menu_path=QString ());
+	struct ComponentOverride {
+		QString context;
+		bool hidden;
+	};
+	typedef QMultiMap<QString, ComponentOverride> OverrideMap;
+	static OverrideMap overrides;
+	QString context;
+
+	void appendPluginToList (const QString &id, QStringList *list);
 };
 
 
-class RKContextMap;
-
 class RKPluginMapParseResult {
 public:
 	RKPluginMapParseResult () : valid_plugins (0) {};
@@ -161,26 +201,30 @@ public:
 	int valid_plugins;
 };
 
-/** This class (only a single instance should ever be needed) keeps a list of named components, which can be made accessible via the menu-structure
+/** This class keeps a list of named components, which can be made accessible via the menu-structure
 or included in other plugins. What this class does is rather simple: It basically maps a two piece name (namespace, component name) to a short description of the component (RKComponentHandle). The most important part of that description is the filename where a more elaborate definition of
 the component can be retrieved.
 
 The RKComponentMap provides convenience functions for adding or removing a .pluginmap-file to/from the list of components, and looking up RKComponentHandle for a given component name.
 
+Usually there is exactly one instance of this class, accessible with RKComonentMap::getMain(), and some other static functions. However, temporary instances can be created for parsing
+individual .pluginmap files in order to list / display the plugins contained in these.
+
 @author Thomas Friedrichsmeier
 */
-class RKComponentMap : public RKComponentGUIXML, public KXMLGUIClient {
+class RKComponentMap : public QObject, public RKComponentGUIXML, public KXMLGUIClient {
+	Q_OBJECT
 public:
 	RKComponentMap ();
-
 	~RKComponentMap ();
 
 /** adds all Plugins / components in a .pluginmap-file. Also takes care of creating the menu-items, etc.
 @returns status info of number of plugins (i.e. stand-alone components/menu-entries) added successfully / failed */
-	static RKPluginMapParseResult addPluginMap (const QString& plugin_map_file);
+	RKPluginMapParseResult addPluginMap (const QString& plugin_map_file);
+	void finalizeAll ();
 
 /** clears out (and deletes) all components / plugins */
-	static void clearAll ();
+	void clearAll ();
 
 /** returns the component identified by id, 0 if not found */
 	static RKComponentHandle* getComponentHandle (const QString &id);
@@ -189,7 +233,7 @@ public:
 	static RKComponentMap *getMap () { return component_map; };
 	static void initialize ();
 /** returns the context identified by id */
-	static RKContextMap *getContext (const QString &id);
+	static RKComponentGUIXML *getContext (const QString &id);
 
 	enum ComponentInvocationMode {
 		ManualSubmit,
@@ -199,31 +243,30 @@ public:
 /** invokes the specified component as toplevel
 @param message If a non-null pointer to QString is given, error messages are written into this string *instead* of being displayed */
 	static bool invokeComponent (const QString &component_id, const QStringList &serialized_settings, ComponentInvocationMode submit_mode = ManualSubmit, QString *message=0, RCommandChain *in_chain = 0);
-/** @returns a list of all currently registered component ids */
-	QStringList allComponentIds () { return components.keys(); };
-	bool isPluginMapLoaded (const QString& abs_filename) { return pluginmapfiles.contains (abs_filename); };
+/** @returns for rk.list.plugins(): Return a list of all currently registered component ids, their context, menu, and label (i.e. current four strings per component) */
+	QStringList listPlugins ();
+	void setPluginStatus (const QStringList &ids, const QStringList &contexts, const QStringList& visible);
+	bool isPluginMapLoaded (const QString& abs_filename) const;
+public slots:
+/** Slot called, when a menu-item for a component is selected. Responsible for creating the GUI. */
+	void activateComponent ();
 private:
 /** typedef for easy reference to iterator */
-	typedef QMap<QString, RKComponentHandle*> ComponentMap;
+	typedef QMultiMap<QString, RKComponentHandle*> ComponentMap;
 /** the actual map of components */
 	ComponentMap components;
 
 	RKComponentHandle* getComponentHandleLocal (const QString &id);
 	QString getComponentIdLocal (RKComponentHandle* component);
-	RKContextMap *getContextLocal (const QString &id);
-	RKPluginMapParseResult addPluginMapLocal (const QString& plugin_map_file);
 
-	void clearLocal ();
-
-	typedef QMap<QString, RKContextMap*> RKComponentContextMap;
+	typedef QMap<QString, RKComponentGUIXML*> RKComponentContextMap;
 	RKComponentContextMap contexts;
 
-	typedef QMap<QString, RKPluginMapFile*> PluginMapFileMap;
-	PluginMapFileMap pluginmapfiles;
+	QList<RKPluginMapFile*> pluginmapfiles;
 
 	static RKComponentMap *component_map;
 friend class RKComponentHandle;
-	// most components have neither attributes specific dependencies (other than dependencies shared by all plugins in a pluginmap).
+	// most components have neither attributes nor specific dependencies (other than dependencies shared by all plugins in a pluginmap).
 	// therefore, it saves a few bytes to store attributes and specific dependencies in a central map, rather than keeping structures
 	// per plugin
 	struct AttributeValueMap {
