@@ -2,8 +2,8 @@
                           rkcomponentproperties  -  description
                              -------------------
     begin                : Fri Nov 25 2005
-    copyright            : (C) 2005, 2006, 2007, 2008, 2009, 2011, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2006, 2007, 2008, 2009, 2011, 2012, 2014, 2015 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -113,11 +113,11 @@ RKComponentPropertyBase::~RKComponentPropertyBase () {
 
 QVariant RKComponentPropertyBase::value (const QString &modifier) {
 	RK_TRACE (PLUGIN);
-	if (!modifier.isEmpty ()) {
-		warnModifierNotRecognized (modifier);
-		return QString ();
-	}
-	return _value;
+	if (modifier.isEmpty ()) return _value;
+	if (modifier == "quoted") return RObject::rQuote (_value);
+	// else
+	warnModifierNotRecognized (modifier);
+	return QString ();
 }
 
 bool RKComponentPropertyBase::setValue (const QString &string) {
@@ -132,7 +132,7 @@ void RKComponentPropertyBase::connectToGovernor (RKComponentPropertyBase *govern
 	RK_TRACE (PLUGIN);
 
 	RK_ASSERT (governor);
-	connect (governor, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (governorValueChanged (RKComponentPropertyBase *)));
+	connect (governor, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (governorValueChanged(RKComponentPropertyBase*)));
 	governor_modifier = modifier;
 	// no need to reconcile any requirements, as the RKComponentPropertyBase does not have any requirements
 
@@ -142,7 +142,9 @@ void RKComponentPropertyBase::connectToGovernor (RKComponentPropertyBase *govern
 
 void RKComponentPropertyBase::governorValueChanged (RKComponentPropertyBase *property) {
 	RK_TRACE (PLUGIN);
-#warning TOOD: connected value should be stored as qvariant
+#ifdef __GNUC__
+#	warning TOOD: connected value should be stored as qvariant
+#endif
 	setValue (property->value (governor_modifier).toString ());
 }
 
@@ -152,17 +154,85 @@ void RKComponentPropertyBase::warnModifierNotRecognized (const QString &modifier
 }
 
 
+///////////////////////////////////////// AbstractList /////////////////////////////////////
+
+QString RKComponentPropertyAbstractList::sep = "\n";
+RKComponentPropertyAbstractList::RKComponentPropertyAbstractList (QObject* parent, bool required) : RKComponentPropertyBase (parent, required) {
+	RK_TRACE (PLUGIN);
+	setAllowedLength ();
+	setStripDuplicates (false);
+}
+
+RKComponentPropertyAbstractList::~RKComponentPropertyAbstractList () {
+	RK_TRACE (PLUGIN);
+}
+
+void RKComponentPropertyAbstractList::setAllowedLength ( int min_num_items, int min_num_items_if_any, int max_num_items ) {
+	RK_TRACE (PLUGIN);
+
+	RKComponentPropertyAbstractList::min_num_items = min_num_items;
+	RKComponentPropertyAbstractList::min_num_items_if_any = min_num_items_if_any;
+	RKComponentPropertyAbstractList::max_num_items = max_num_items;
+	is_valid = checkListLength ();
+}
+
+bool RKComponentPropertyAbstractList::checkListLength () {
+	RK_TRACE (PLUGIN);
+
+	if ((min_num_items > 0) || (max_num_items > 0) || (min_num_items_if_any > 0)) {
+		int len = listLength ();
+		if (len < min_num_items) return false;
+		if (len && (len < min_num_items_if_any)) return false;
+		if ((max_num_items > 0) && (len > max_num_items)) return false;
+	}
+	return true;
+}
+
+void RKComponentPropertyAbstractList::reconcileLengthRequirements (RKComponentPropertyAbstractList* governor) {
+	RK_TRACE (PLUGIN);
+
+	if (governor->min_num_items < min_num_items) governor->min_num_items = min_num_items;
+	if (governor->min_num_items_if_any < min_num_items_if_any) governor->min_num_items_if_any = min_num_items_if_any;
+	if (max_num_items && (governor->max_num_items > max_num_items)) governor->max_num_items = max_num_items;
+}
+
+void RKComponentPropertyAbstractList::connectToGovernor (RKComponentPropertyBase* governor, const QString& modifier, bool reconcile_requirements) {
+	RK_TRACE (PLUGIN);
+
+	if (reconcile_requirements && modifier.isEmpty ()) {
+		if ((governor->type () == PropertyStringList) || (governor->type () == PropertyRObjects)) {
+			reconcileLengthRequirements (static_cast<RKComponentPropertyAbstractList*> (governor));
+		}
+	}
+
+	RKComponentPropertyBase::connectToGovernor (governor, modifier, reconcile_requirements);
+}
+
+
 ///////////////////////////////////////// StringList ///////////////////////////////////////
 
-RKComponentPropertyStringList::RKComponentPropertyStringList (QObject *parent, bool required) : RKComponentPropertyBase (parent, required) {
+RKComponentPropertyStringList::RKComponentPropertyStringList (QObject *parent, bool required) : RKComponentPropertyAbstractList (parent, required) {
 	RK_TRACE (PLUGIN);
-	sep = "\n";
 }
 
 RKComponentPropertyStringList::~RKComponentPropertyStringList () {
 	RK_TRACE (PLUGIN);
 }
 
+// escapes only newlines, so we can join strings by newline. Does duplicate backslashes, so the string can safely be passed through RKCommonFunction::unescape().
+QString escapeNewlines (const QString &in) {
+	QString out;
+
+	for (int i = 0; i < in.size (); ++i) {
+		QChar c = in[i];
+		if (c == '\\') out.append ("\\\\");
+		else if (c == '\n') out.append ("\\n");
+		else out.append (c);
+	}
+
+	return out;
+}
+
 QVariant RKComponentPropertyStringList::value (const QString &modifier) {
 	RK_TRACE (PLUGIN);
 
@@ -172,7 +242,7 @@ QVariant RKComponentPropertyStringList::value (const QString &modifier) {
 		if (_value.isNull ()) {
 			for (int i = 0; i < storage.size (); ++i) {
 				if (!_value.isEmpty ()) _value.append (sep);
-				_value.append (RKCommonFunctions::escape (storage[i]));	// _value acts as a cache for joined string
+				_value.append (escapeNewlines (storage[i]));	// _value acts as a cache for joined string
 			}
 		}
 		return _value;
@@ -184,13 +254,13 @@ QVariant RKComponentPropertyStringList::value (const QString &modifier) {
 
 bool RKComponentPropertyStringList::setValue (const QString &string) {
 	if (string.isNull ()) {
-		setValues (QStringList ());
+		setValueList (QStringList ());
 	} else {
 		QStringList list = string.split (sep);
 		for (int i = 0; i < list.size (); ++i) {
 			list[i] = RKCommonFunctions::unescape (list[i]);
 		}
-		setValues (list);
+		setValueList (list);
 	}
 	return true;
 }
@@ -198,6 +268,8 @@ bool RKComponentPropertyStringList::setValue (const QString &string) {
 void RKComponentPropertyStringList::setValueAt (int index, const QString& value) {
 	RK_TRACE (PLUGIN);
 	
+	if (getStripDuplicates () && storage.contains (value)) return;
+	
 	while (index >= storage.size ()) storage.append (QString ());	// expand as needed
 	storage[index] = value;
 	doChange ();
@@ -206,12 +278,40 @@ void RKComponentPropertyStringList::setValueAt (int index, const QString& value)
 void RKComponentPropertyStringList::governorValueChanged (RKComponentPropertyBase *property) {
 	QVariant value = property->value (governor_modifier);
 	if (value.type () == QVariant::StringList) {
-		setValues (value.toStringList ());
+		setValueList (value.toStringList ());
 	} else {
 		setValue (value.toString ());
 	}
 }
 
+void RKComponentPropertyStringList::checkStripDuplicates () {
+	if (!getStripDuplicates ()) return;
+	RK_TRACE (PLUGIN);
+
+	QStringList unique;
+	for (int i = 0; i < storage.size (); ++i) {
+		if (!unique.contains (storage[i])) unique.append (storage[i]);
+	}
+	storage = unique;
+}
+
+void RKComponentPropertyStringList::removeAt (int index) {
+	RK_TRACE (PLUGIN);
+	if ((index < 0) || (index >= storage.size ())) {
+		RK_ASSERT (false);
+		return;
+	}
+	storage.removeAt (index);
+	doChange ();
+}
+
+void RKComponentPropertyStringList::doChange () {
+	RK_TRACE (PLUGIN);
+	is_valid = checkListLength ();
+	_value.clear ();
+	emit (valueChanged (this));
+}
+
 ///////////////////////////////////////////// Bool //////////////////////////////////////////
 
 RKComponentPropertyBool::RKComponentPropertyBool (QObject *parent, bool required, bool default_state, const QString &value_true, const QString &value_false) : RKComponentPropertyBase (parent, required) {
@@ -233,15 +333,15 @@ RKComponentBase* RKComponentPropertyBool::lookupComponent (const QString &identi
 	RKComponentBase *dummy = RKComponentPropertyBase::lookupComponent (identifier, remainder);
 	if (dummy != this) return dummy;
 
-	QString next = identifier.section (".", 0, 0);
+	QString next = identifier.section ('.', 0, 0);
 	if (next == "not") {
 		RKComponentPropertyBool *negated = new RKComponentPropertyBool (this, false, false, value_true, value_false);
 		negated->setInverted (true);
 		negated->setInternal (true);
 		negated->connectToGovernor (this);
-		*remainder = QString::null;		// reset
+		*remainder = QString ();		// reset
 		addChild ("not", negated);		// so subsequent lookups will not recreate the negated property
-		return (negated->lookupComponent (identifier.section (".", 1), remainder));
+		return (negated->lookupComponent (identifier.section ('.', 1), remainder));
 	}
 
 	return (this);
@@ -270,6 +370,7 @@ bool RKComponentPropertyBool::stringToBool (const QString &value, bool *ok) {
 
 	if (value == "true") return true;
 	if (value == "false") return false;
+	if (value.isEmpty ()) return false;
 	
 	if (ok) *ok = false;
 	return false;
@@ -457,13 +558,10 @@ bool RKComponentPropertyInt::isStringValid (const QString &string) {
 
 void RKComponentPropertyInt::connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier, bool reconcile_requirements) {
 	RK_TRACE (PLUGIN);
-
 	RK_ASSERT (governor);
-	connect (governor, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (governorValueChanged (RKComponentPropertyBase *)));
-	governor_modifier = modifier;
 
 	// reconcile requirements if applicable
-	if (reconcile_requirements && governor_modifier.isEmpty ()) {
+	if (reconcile_requirements && modifier.isEmpty ()) {
 		if (governor->type () == PropertyInt) {
 			RKComponentPropertyInt *igov = static_cast<RKComponentPropertyInt *> (governor); 	// convenience pointer
 			if (validator->bottom () > igov->minValue ()) {
@@ -483,8 +581,7 @@ void RKComponentPropertyInt::connectToGovernor (RKComponentPropertyBase *governo
 		}
 	}
 
-	// fetch current value
-	governorValueChanged (governor);
+	RKComponentPropertyBase::connectToGovernor (governor, modifier, reconcile_requirements);
 }
 
 void RKComponentPropertyInt::governorValueChanged (RKComponentPropertyBase *property) {
@@ -616,13 +713,10 @@ bool RKComponentPropertyDouble::isStringValid (const QString &string) {
 
 void RKComponentPropertyDouble::connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier, bool reconcile_requirements) {
 	RK_TRACE (PLUGIN);
-
 	RK_ASSERT (governor);
-	connect (governor, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (governorValueChanged (RKComponentPropertyBase *)));
-	governor_modifier = modifier;
 
 	// reconcile requirements if applicable
-	if (reconcile_requirements && governor_modifier.isEmpty ()) {
+	if (reconcile_requirements && modifier.isEmpty ()) {
 		if (governor->type () == PropertyInt) {
 			RKComponentPropertyInt *igov = static_cast<RKComponentPropertyInt *> (governor); 	// convenience pointer
 			if (validator->bottom () > igov->minValue ()) {
@@ -642,8 +736,7 @@ void RKComponentPropertyDouble::connectToGovernor (RKComponentPropertyBase *gove
 		}
 	}
 
-	// fetch current value
-	governorValueChanged (governor);
+	RKComponentPropertyBase::connectToGovernor (governor, modifier, reconcile_requirements);
 }
 
 void RKComponentPropertyDouble::governorValueChanged (RKComponentPropertyBase *property) {
@@ -702,12 +795,13 @@ void RKComponentPropertyDouble::internalSetValue (const QString &new_value) {
 #include "../core/rkmodificationtracker.h"
 #include "../misc/rkobjectlistview.h"
 
-RKComponentPropertyRObjects::RKComponentPropertyRObjects (QObject *parent, bool required) : RKComponentPropertyBase (parent, required), RObjectListener (RObjectListener::Other) {
+RKComponentPropertyRObjects::RKComponentPropertyRObjects (QObject *parent, bool required) : RKComponentPropertyAbstractList (parent, required), RObjectListener (RObjectListener::Other) {
 	RK_TRACE (PLUGIN);
 
 // no initial requirements
-	dims = min_length = max_length = min_num_objects = min_num_objects_if_any = max_num_objects = -1;
-	separator = "\n";
+	dims = min_length = max_length = 0;
+	problems_are_errors = true;
+	setStripDuplicates (true);      // legacy default
 
 	addNotificationType (RObjectListener::ObjectRemoved);
 	addNotificationType (RObjectListener::MetaChanged);
@@ -716,23 +810,13 @@ RKComponentPropertyRObjects::RKComponentPropertyRObjects (QObject *parent, bool
 RKComponentPropertyRObjects::~RKComponentPropertyRObjects () {
 	RK_TRACE (PLUGIN);
 
-	setObjectValue (0);
-}
-
-void RKComponentPropertyRObjects::setListLength (int min_num_objects, int min_num_objects_if_any, int max_num_objects) {
-	RK_TRACE (PLUGIN);
-
-	RKComponentPropertyRObjects::min_num_objects = min_num_objects;
-	RKComponentPropertyRObjects::min_num_objects_if_any = min_num_objects_if_any;
-	RKComponentPropertyRObjects::max_num_objects = max_num_objects;
-
-	validizeAll ();
+	setObjectValueSilent (0);
 }
 
 bool RKComponentPropertyRObjects::addObjectValue (RObject *object) {
 	RK_TRACE (PLUGIN);
 
-	if (appendObject (object)) {
+	if (addObjectValueSilent (object)) {
 		updateValidity ();
 		emit (valueChanged (this));
 		return isValid ();
@@ -740,22 +824,25 @@ bool RKComponentPropertyRObjects::addObjectValue (RObject *object) {
 	return false;
 }
 
-bool RKComponentPropertyRObjects::appendObject (RObject *object) {
-	if ((!object) || object_list.contains (object)) return false;
+bool RKComponentPropertyRObjects::addObjectValueSilent (RObject *object) {
+	if (!object) return false;
+	bool is_dupe = object_list.contains (object);
+	if (getStripDuplicates () && is_dupe) return false;
 
 	object_list.append (object);
-	QString probs = checkObjectProblems (object);
-	if (!probs.isEmpty ()) problems.insert (object, probs);
-	listenForObject (object);
+	if (!is_dupe) {
+		QString probs = checkObjectProblems (object);
+		if (!probs.isEmpty ()) problems.insert (object, probs);
+		listenForObject (object);
+	}
 	return true;
 }
 
 void RKComponentPropertyRObjects::objectRemoved (RObject *object) {
 	RK_TRACE (PLUGIN);
 
-	int index = object_list.indexOf (object);
-	if (index >= 0) {
-		object_list.removeAt (index);
+	int removals = object_list.removeAll (object);
+	if (removals) {
 		problems.remove (object);
 		stopListenForObject (object);
 		updateValidity ();
@@ -763,6 +850,19 @@ void RKComponentPropertyRObjects::objectRemoved (RObject *object) {
 	}
 }
 
+void RKComponentPropertyRObjects::removeAt (int index) {
+	RK_TRACE (PLUGIN);
+	if ((index < 0) || (index >= object_list.size ())) {
+		RK_ASSERT (false);
+		return;
+	}
+	RObject* obj = object_list.takeAt (index);
+	problems.remove (obj);
+	if (!object_list.contains (obj)) stopListenForObject (obj);
+	updateValidity ();
+	emit (valueChanged (this));
+}
+
 void RKComponentPropertyRObjects::setClassFilter (const QStringList &classes) {
 	RK_TRACE (PLUGIN);
 
@@ -786,40 +886,33 @@ void RKComponentPropertyRObjects::setDimensionFilter (int dimensionality, int mi
 	validizeAll ();
 }
 
-bool RKComponentPropertyRObjects::setObjectValue (RObject *object) {
+bool RKComponentPropertyRObjects::setObjectValueSilent (RObject* object) {
 	RK_TRACE (PLUGIN);
 
 	problems.clear ();
-	while (!object_list.isEmpty ()) {
-		stopListenForObject (object_list.takeAt (0));
+	QSet<RObject*> unique = object_list.toSet ();
+	foreach (RObject *obj, unique) {
+		stopListenForObject (obj);
 	}
-	return (addObjectValue (object));
+	object_list.clear ();
+	return (addObjectValueSilent (object));
+}
+
+bool RKComponentPropertyRObjects::setObjectValue (RObject *object) {
+	setObjectValueSilent (object);
+	updateValidity ();
+	emit (valueChanged (this));
+	return isValid ();
 }
 
 void RKComponentPropertyRObjects::setObjectList (const RObject::ObjectList &newlist) {
 	RK_TRACE (PLUGIN);
 
-	bool changes = false;
-
-	// remove items from the old list that are not in the new list
-	for (int i = 0; i < object_list.size (); ++i) {
-		RObject *object = object_list[i];
-		if (!newlist.contains (object)) {
-			stopListenForObject (object_list.takeAt (i));
-			problems.remove (object);
-			--i;
-			changes = true;
+	if (newlist != object_list) {
+		setObjectValueSilent (0);
+		for (int i = 0; i < newlist.size (); ++i) {
+			addObjectValueSilent (newlist[i]);
 		}
-	}
-
-	// now add items from the new list that are not in the old list
-	for (int i = 0; i < newlist.size (); ++i) {
-		RObject *obj = newlist[i];
-		if (appendObject (obj)) changes = true;
-	}
-
-	// emit a signal if there have been any changes
-	if (changes) {
 		updateValidity ();
 		emit (valueChanged (this));
 	}
@@ -859,7 +952,7 @@ QString RKComponentPropertyRObjects::checkObjectProblems (RObject *object) const
 	if (!types.isEmpty ()) {
 		QString type = RObject::typeToText (object->getDataType ()).toLower ();
 		if (!types.contains (type)) {
-			probs.append (i18n ("This object's data type is <i>%1</i>, while allowed type(s) is/are <i>%2</i>.", type, types.join (", ")));
+			probs.append (i18n ("This object's data type is <i>%1</i>, while expected type(s) is/are <i>%2</i>.", type, types.join (", ")));
 		}
 	}
 
@@ -902,7 +995,7 @@ QVariant RKComponentPropertyRObjects::value (const QString &modifier) {
 	return ret;
 }
 
-bool RKComponentPropertyRObjects::setValue (const QStringList& values) {
+bool RKComponentPropertyRObjects::setValueList (const QStringList& values) {
 	RK_TRACE (PLUGIN);
 
 	setObjectValue (0);
@@ -910,7 +1003,7 @@ bool RKComponentPropertyRObjects::setValue (const QStringList& values) {
 	bool ok = true;
 	for (int i = 0; i < values.size (); ++i) {
 		RObject *obj = RObjectList::getObjectList ()->findObject (values[i]);
-		ok = ok && appendObject (obj);
+		ok &= addObjectValueSilent (obj);
 	}
 
 	updateValidity ();
@@ -921,13 +1014,13 @@ bool RKComponentPropertyRObjects::setValue (const QStringList& values) {
 bool RKComponentPropertyRObjects::setValue (const QString &value) {
 	RK_TRACE (PLUGIN);
 
-	return setValue (value.split (separator, QString::SkipEmptyParts));
+	return setValueList (value.split (sep, QString::SkipEmptyParts));
 }
 
 bool RKComponentPropertyRObjects::isStringValid (const QString &value) {
 	RK_TRACE (PLUGIN);
 
-	QStringList slist = value.split (separator, QString::SkipEmptyParts);
+	QStringList slist = value.split (sep, QString::SkipEmptyParts);
 
 	for (QStringList::const_iterator it = slist.begin (); it != slist.end (); ++it) {
 		RObject *obj = RObjectList::getObjectList ()->findObject (*it);
@@ -941,13 +1034,10 @@ bool RKComponentPropertyRObjects::isStringValid (const QString &value) {
 
 void RKComponentPropertyRObjects::connectToGovernor (RKComponentPropertyBase *governor, const QString &modifier, bool reconcile_requirements) {
 	RK_TRACE (PLUGIN);
-
 	RK_ASSERT (governor);
-	connect (governor, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (governorValueChanged (RKComponentPropertyBase *)));
-	governor_modifier = modifier;
 
 	// reconcile requirements if applicable
-	if (reconcile_requirements && governor_modifier.isEmpty ()) {
+	if (reconcile_requirements && modifier.isEmpty ()) {
 		if (governor->type () == PropertyRObjects) {
 			RKComponentPropertyRObjects *ogov = static_cast<RKComponentPropertyRObjects *> (governor); 	// convenience pointer
 
@@ -968,17 +1058,6 @@ void RKComponentPropertyRObjects::connectToGovernor (RKComponentPropertyBase *go
 				}
 			}
 
-			// reconcile number of objects filter
-			if (ogov->min_num_objects < min_num_objects) {
-				ogov->min_num_objects = min_num_objects;
-			}
-			if (ogov->min_num_objects_if_any < min_num_objects_if_any) {
-				ogov->min_num_objects_if_any = min_num_objects_if_any;
-			}
-			if (max_num_objects && (ogov->max_num_objects > max_num_objects)) {
-				ogov->max_num_objects = max_num_objects;
-			}
-
 			// reconcile class filter
 			if (!classes.isEmpty ()) {
 				if (ogov->classes.isEmpty ()) {
@@ -1024,8 +1103,7 @@ void RKComponentPropertyRObjects::connectToGovernor (RKComponentPropertyBase *go
 		}
 	}
 
-	// fetch current value
-	governorValueChanged (governor);
+	RKComponentPropertyAbstractList::connectToGovernor (governor, modifier, reconcile_requirements);
 }
 
 void RKComponentPropertyRObjects::governorValueChanged (RKComponentPropertyBase *property) {
@@ -1036,7 +1114,7 @@ void RKComponentPropertyRObjects::governorValueChanged (RKComponentPropertyBase
 	} else {
 		QVariant value = property->value ();
 		if (value.type () == QVariant::StringList) {
-			setValue (value.toStringList ());
+			setValueList (value.toStringList ());
 		} else {
 			setValue (value.toString ());
 		}
@@ -1085,25 +1163,16 @@ void RKComponentPropertyRObjects::updateValidity () {
 
 	is_valid = true;	// innocent until proven guilty
 
-	if (!problems.isEmpty ()) is_valid = false;
-	else if ((min_num_objects > 0) || (max_num_objects > 0) || (min_num_objects_if_any > 0)) {
-		int len = object_list.count ();
-		if (len < min_num_objects) is_valid = false;
-		if (len && (len < min_num_objects_if_any)) is_valid = false;
-		if ((max_num_objects > 0) && (len > max_num_objects)) is_valid = false;
-	}
+	if (problems_are_errors && (!problems.isEmpty ())) is_valid = false;
+	else is_valid = checkListLength ();
 }
 
-bool RKComponentPropertyRObjects::atMaxLength () {
+void RKComponentPropertyRObjects::setObjectProblemsAreErrors (bool errors) {
 	RK_TRACE (PLUGIN);
-
-	int len = object_list.count ();
-	if (max_num_objects && (len >= max_num_objects)) return true;
-	return false;
+	problems_are_errors = errors;
+	updateValidity ();
 }
 
-
-
 /////////////////////////////////////////// Code ////////////////////////////////////////////////
 
 RKComponentPropertyCode::RKComponentPropertyCode (QObject *parent, bool required) : RKComponentPropertyBase (parent, required) {
@@ -1136,7 +1205,7 @@ RKComponentPropertyConvert::RKComponentPropertyConvert (RKComponent *parent) : R
 	require_true = false;
 	c_parent = parent;
 	// get notified of own changes
-	connect (this, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (selfChanged (RKComponentPropertyBase *)));
+	connect (this, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (selfChanged(RKComponentPropertyBase*)));
 }
 
 RKComponentPropertyConvert::~RKComponentPropertyConvert () {
@@ -1160,7 +1229,7 @@ void RKComponentPropertyConvert::setSources (const QStringList &source_ids) {
 		if (prop && prop->isProperty ()) {
 			s.property = static_cast<RKComponentPropertyBase *>(prop);
 			sources.append (s);
-			connect (s.property, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (sourcePropertyChanged (RKComponentPropertyBase *)));
+			connect (s.property, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (sourcePropertyChanged(RKComponentPropertyBase*)));
 		} else {
 			RK_DEBUG (PLUGIN, DL_WARNING, "Not found or not a property: %s", (*it).toLatin1 ().data ());
 		}
@@ -1306,7 +1375,7 @@ void RKComponentPropertySwitch::connectToGovernor (RKComponentPropertyBase*, con
 	RK_DEBUG (PLUGIN, DL_ERROR, "Cannot connect a <switch> property to a governor");
 }
 
-bool RKComponentPropertySwitch::setValue (const QString& value) {
+bool RKComponentPropertySwitch::setValue (const QString&) {
 	RK_DEBUG (PLUGIN, DL_ERROR, "Cannot set value for a <switch> property");
 	return false;
 }
@@ -1368,7 +1437,8 @@ void RKComponentPropertySwitch::setSources (const QString& _condition_prop, cons
 
 	for (int i = 0; i < _value_props.size (); ++i) {
 		QString mod;
-		RKComponentPropertyBase *p = c_parent->lookupProperty (_value_props[i], &mod, true);
+		RKComponentPropertyBase *p = 0;
+		if (!_value_props[i].isEmpty ()) p = c_parent->lookupProperty (_value_props[i], &mod, true);	// Don't try to look it up, if it's empty (as it always is for fixed_value, as this would generate a warning.)
 		value_props.append (p);	// NOTE: Even if it is 0. value() takes care of that.
 		value_prop_mods.append (mod);
 		if (p) connect (p, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (sourcePropertyChanged(RKComponentPropertyBase*)));
