@@ -2,8 +2,8 @@
                           rkdropdown.h  -  description
                              -------------------
     begin                : Fri Jan 12 2007
-    copyright            : (C) 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2007, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,13 +33,13 @@ RKDropDown::RKDropDown (const QDomElement &element, RKComponent *parent_componen
 	RK_TRACE (PLUGIN);
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create layout
 	QVBoxLayout *vbox = new QVBoxLayout (this);
 	vbox->setContentsMargins (0, 0, 0, 0);
 
-	QLabel *label = new QLabel (xml->getStringAttribute (element, "label", i18n ("Select one:"), DL_INFO), this);
+	label = new QLabel (xml->i18nStringAttribute (element, "label", i18n ("Select one:"), DL_INFO), this);
 	vbox->addWidget (label);
 
 	// create ComboBox
@@ -52,7 +52,7 @@ RKDropDown::RKDropDown (const QDomElement &element, RKComponent *parent_componen
 	addOptionsAndInit (element);
 
 	vbox->addWidget (box);
-	connect (box, SIGNAL (activated (int)), this, SLOT (comboItemActivated (int)));
+	connect (box, SIGNAL (activated(int)), this, SLOT (comboItemActivated(int)));
 }
 
 RKDropDown::~RKDropDown(){
@@ -88,4 +88,12 @@ void RKDropDown::setItemEnabledInGUI (int id, bool enabled) {
 	item->setFlags ((Qt::ItemFlags) flags);
 }
 
+QStringList RKDropDown::getUiLabelPair () const {
+	RK_TRACE (PLUGIN);
+
+	QStringList ret (stripAccelerators (label->text ()));
+	ret.append (stripAccelerators (box->currentText ()));
+	return ret;
+}
+
 #include "rkdropdown.moc"
