@@ -2,8 +2,8 @@
                           rkpluginbrowser  -  description
                              -------------------
     begin                : Sat Mar 10 2005
-    copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2012 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2012, 2014 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -30,11 +30,11 @@ RKPluginBrowser::RKPluginBrowser (const QDomElement &element, RKComponent *paren
 	RK_TRACE (PLUGIN);
 
 	// get xml-helper
-	XMLHelper *xml = XMLHelper::getStaticHelper ();
+	XMLHelper *xml = parent_component->xmlHelper ();
 
 	// create and add property
 	addChild ("selection", selection = new RKComponentPropertyBase (this, true));
-	connect (selection, SIGNAL (valueChanged (RKComponentPropertyBase *)), this, SLOT (textChanged (RKComponentPropertyBase *)));
+	connect (selection, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (textChanged(RKComponentPropertyBase*)));
 
 	setRequired (xml->getBoolAttribute (element, "required", true, DL_INFO));
 	connect (requirednessProperty (), SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (requirednessChanged(RKComponentPropertyBase*)));
@@ -50,13 +50,14 @@ RKPluginBrowser::RKPluginBrowser (const QDomElement &element, RKComponent *paren
 
 	bool only_local = !xml->getBoolAttribute (element, "allow_urls", false, DL_INFO);
 
-	selector = new GetFileNameWidget (this, mode, only_local, xml->getStringAttribute (element, "label", i18n ("Enter filename"), DL_INFO), i18n ("Select"), xml->getStringAttribute (element, "initial", QString::null, DL_INFO));
-	QString filter = xml->getStringAttribute (element, "filter", QString::null, DL_INFO);
+	label_string = xml->i18nStringAttribute (element, "label", i18n ("Enter filename"), DL_INFO);
+	selector = new GetFileNameWidget (this, mode, only_local, label_string, i18n ("Select"), xml->getStringAttribute (element, "initial", QString (), DL_INFO));
+	QString filter = xml->getStringAttribute (element, "filter", QString (), DL_INFO);
 	if (!filter.isEmpty ()) {
 		filter.append ("\n*|All files");
 		selector->setFilter (filter);
 	}
-	connect (selector, SIGNAL (locationChanged ()), SLOT (textChanged ()));
+	connect (selector, SIGNAL (locationChanged()), SLOT (textChanged()));
 
 	vbox->addWidget (selector);
 
@@ -112,4 +113,12 @@ void RKPluginBrowser::updateColor () {
 	}
 }
 
+QStringList RKPluginBrowser::getUiLabelPair () const {
+	RK_TRACE (PLUGIN);
+
+	QStringList ret (label_string);
+	ret.append (selection->value ().toString ());
+	return ret;
+}
+
 #include "rkpluginbrowser.moc"
