@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Aug 11 2004
     copyright            : (C) 2004, 2006, 2009, 2012, 2014 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -50,7 +50,7 @@ RKPluginSpinBox::RKPluginSpinBox (const QDomElement &element, RKComponent *paren
 	if (!intmode) {
 		double min = xml->getDoubleAttribute (element, "min", -FLT_MAX, DL_INFO);
 		double max = xml->getDoubleAttribute (element, "max", FLT_MAX, DL_INFO);
-		double initial = xml->getDoubleAttribute (element, "initial", qMin (max, qMax (min, qreal(0.0))), DL_INFO);
+		double initial = xml->getDoubleAttribute (element, "initial", qMin (max, qMax (min, double (qreal(0.0)))), DL_INFO);
 		int default_precision = xml->getIntAttribute (element, "default_precision", 2, DL_INFO);
 		int max_precision = xml->getIntAttribute (element, "max_precision", 8, DL_INFO);
 
