@@ -34,7 +34,7 @@
 #include <QTemporaryFile>
 #include <QDir>
 
-	extern "C" void RK_setupGettext (const char*);
+	void RK_setupGettext (const char*);
 	int RK_Debug_Level = 2;
 	int RK_Debug_Flags = DEBUG_ALL;
 	QMutex RK_Debug_Mutex;
