@@ -3,7 +3,7 @@
                              -------------------
     begin                : Mon Mar 18 20:06:08 CET 2013
     copyright            : (C) 2013-2014 by Thomas Friedrichsmeier 
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
