@@ -1,62 +1,37 @@
 ## Internal functions manipulating graphics should be stored here.
 ## These functions are _not_ supposed to be called by the end user.
 
-# overriding x11 to get informed, when a new x11 window is opened
+#' DEPRECATED: \code{rk.screen.device} is obsolete. It simply calls \code{dev.new()} in this version of RKWard.
+#'
+#' Depending on your use case, you should use \code{dev.new()}, \code{RK()} or \code{rk.embed.device()}, instead.
+#'
+#' @seealso \link{dev.new}, \link{RK}, \link{rk.embed.device}
+#'
 #' @export
-"rk.screen.device" <- function (..., is.being.duplicated = FALSE, is.preview.device = FALSE) {
-	.rk.do.call ("startOpenX11", as.character (dev.cur ()));
-
-	old_dev <- dev.cur ()
-
-	args <- list (...)
-	if (!exists (".rk.default.device")) {
-		if (base::.Platform$OS.type == "unix") {
-			device <- grDevices::x11
-		} else {
-			device <- grDevices::windows
-			if (is.null (args[["width"]])) args[["width"]] <- options ("rk.screendevice.width")[[1]]
-			if (!is.numeric (args[["width"]])) args[["width"]] <- 7
-			if (is.null (args[["height"]])) args[["height"]] <- options ("rk.screendevice.height")[[1]]
-			if (!is.numeric (args[["height"]])) args[["height"]] <- 7
-		}
-	} else {
-		device <- .rk.default.device
-		if (is.character (.rk.default.device)) {
-			device <- get (.rk.default.device)
-		}
-	}
-	x <- do.call (device, args)
-
-	.rk.do.call ("endOpenX11", as.character (dev.cur ()));
-
-	if (getOption ("rk.enable.graphics.history"))
-		rk.record.plot$onAddDevice (old_dev, dev.cur (), is.being.duplicated, is.preview.device)
-
-	invisible (x)
+"rk.screen.device" <- function (...) {
+	warning ("rk.screen.device() is obsolete.\nUse one of dev.new(), RK(), or rk.embed.device(), instead.")
+	dev.new (...)
 }
 
-#' @export
-"x11" <- rk.screen.device
-
-#' @export
-"X11" <- x11
-
-if (base::.Platform$OS.type == "windows") {
-	  "windows" = rk.screen.device
-	  "win.graph" = rk.screen.device
+# Fetch the current size of the given RK() device from the frontend, and redraw
+"RK.resize" <- function (devnum) {
+	# Note: RK.resize() often fails, if something is currently being plotted. That's usually benign, and should not produce warning messages.
+	try (.Call ("rk.graphics.device.resize", as.integer (devnum)-1, PACKAGE="(embedding)"), silent=TRUE)
 }
 
-# set from rkward the application:
-# options(device="rk.screen.device")
 #' @include internal.R
 assign(".rk.preview.devices", list (), envir=.rk.variables)
 
 #' @export
 ".rk.startPreviewDevice" <- function (x) {
+	# NOTE: I considered rewriting this to use .rk.create.preview.data(), but it did not seem right
+	# 1. Creation and removal of storage is mostly trivial
+	# 2. Plot previews need some extra logic for handling deivce closes (see .rk.discard.preview.device.num()), and implementing
+	#    this is easier, if plot preview data is kept in an entirely separate storage
 	a <- .rk.variables$.rk.preview.devices[[x]]
 	if (is.null (a)) {
 		devnum <- dev.cur ()
-		x11 (is.preview.device = TRUE)
+		rk.without.plot.history (dev.new ())
 		if (devnum != dev.cur ()) {
 			.rk.variables$.rk.preview.devices[[x]] <- list (devnum=dev.cur(), par=par (no.readonly=TRUE))
 		} else {
@@ -142,17 +117,14 @@ assign(".rk.preview.devices", list (), envir=.rk.variables)
 		function (...)
 			lattice::lattice.options (print.function = function (x, ...)
 			{
-				if (dev.cur() == 1) rk.screen.device ()
+				if (dev.cur() == 1) dev.new ()
 				## TODO: use "trellis" instead of "lattice" to accomodate ggplot2 plots?
 				plot_hist_enabled <- getOption ("rk.enable.graphics.history")
 				if (plot_hist_enabled) {
 					rk.record.plot$record (nextplot.pkg = "lattice")
-					on.exit (options (rk.enable.graphics.history=TRUE))
-					options (rk.enable.graphics.history=FALSE)	# avoid duplicate trigger inside plot(), below
 				}
-				plot (x, ...)
+				rk.without.plot.history (plot (x, ...))
 				if (plot_hist_enabled) {
-					options (rk.enable.graphics.history=TRUE)
 					rk.record.plot$.save.tlo.in.hP ()
 				}
 				invisible ()
