@@ -3,7 +3,7 @@
                              -------------------
     begin                : Wed Jul 28 2004
     copyright            : (C) 2004, 2007 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -86,7 +86,7 @@ update themselves on certain changed settings should connect to those signals. *
 class RKSettingsTracker : public QObject {
 	Q_OBJECT
 public:
-	RKSettingsTracker (QObject *parent);
+	explicit RKSettingsTracker (QObject *parent);
 	~RKSettingsTracker ();
 
 	void signalSettingsChange (RKSettings::SettingsPage page);
