@@ -3,7 +3,7 @@
                              -------------------
     begin                : Thu Aug 26 2004
     copyright            : (C) 2004 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -40,7 +40,6 @@ public:
 	static void saveSettings (KConfig *config);
 	static void loadSettings (KConfig *config);
 	
-	bool hasChanges ();
 	void applyChanges ();
 	void save (KConfig *config);
 	void validateGUI ();
