@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri Feb 25 2005
     copyright            : (C) 2005, 2006, 2007, 2009, 2010, 2011 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -83,7 +83,7 @@ RKHelpSearchWindow::RKHelpSearchWindow (QWidget *parent, bool tool_window, const
 	field = new QComboBox (this);
 	field->setEditable (true);
 	field->setSizePolicy (QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
-	connect (field->lineEdit () , SIGNAL (returnPressed ()), this, SLOT (slotFindButtonClicked ()));
+	connect (field->lineEdit () , SIGNAL (returnPressed()), this, SLOT (slotFindButtonClicked()));
 	main_settings_layout->addWidget (field);
 
 	QHBoxLayout* fields_packages_layout = new QHBoxLayout ();
@@ -118,7 +118,7 @@ RKHelpSearchWindow::RKHelpSearchWindow (QWidget *parent, bool tool_window, const
 
 	findButton = new QPushButton (i18n ("Find"), this);
 	findButton->setSizePolicy (QSizePolicy::Fixed, QSizePolicy::Fixed);
-	connect (findButton, SIGNAL (clicked ()), this, SLOT (slotFindButtonClicked ()));
+	connect (findButton, SIGNAL (clicked()), this, SLOT (slotFindButtonClicked()));
 	selection_layout->addWidget (findButton);
 
 	results = new RKHelpSearchResultsModel (this);
@@ -128,7 +128,7 @@ RKHelpSearchWindow::RKHelpSearchWindow (QWidget *parent, bool tool_window, const
 	results_view->setRootIsDecorated (false);
 	results_view->setModel (proxy_model);
 	results_view->setSortingEnabled (true);
-	connect (results_view, SIGNAL (doubleClicked(const QModelIndex&)), this, SLOT (resultDoubleClicked(const QModelIndex&)));
+	connect (results_view, SIGNAL (doubleClicked(QModelIndex)), this, SLOT (resultDoubleClicked(QModelIndex)));
 	main_layout->addWidget (results_view);
 
 	setCaption (i18n ("Help search"));
@@ -199,9 +199,9 @@ void RKHelpSearchWindow::slotFindButtonClicked () {
 
 	QString fields = fieldsList->itemData (fieldsList->currentIndex ()).toString ();
 
-	QString s = ".rk.get.search.results (" + RObject::rQuote (field->currentText ()) + ", agrep=" + agrep + ", ignore.case=" + ignoreCase + package + ", fields=" + fields +")";
+	QString s = ".rk.get.search.results (" + RObject::rQuote (field->currentText ()) + ", agrep=" + agrep + ", ignore.case=" + ignoreCase + package + ", fields=" + fields + ')';
 	
-	RKGlobals::rInterface ()->issueCommand (s, RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString::null, this, HELP_SEARCH, 0);
+	RKGlobals::rInterface ()->issueCommand (s, RCommand::App | RCommand::Sync | RCommand::GetStringVector, QString (), this, HELP_SEARCH, 0);
 	setEnabled (false);
 	field->addItem (field->currentText ());
 }
@@ -255,7 +255,7 @@ void RKHelpSearchWindow::rCommandDone (RCommand *command) {
 		setEnabled(true);
 	} else if (command->getFlags () == GET_HELP) {
 		if (command->failed ()) {
-			KMessageBox::sorry (this, i18n ("No help found on '%1'. Maybe the corresponding package is not installed/loaded, or maybe you mistyped the command. Try using Help->Search R Help for more options.", command->command ().section ("\"", 1, 1)), i18n ("No help found"));
+			KMessageBox::sorry (this, i18n ("No help found on '%1'. Maybe the corresponding package is not installed/loaded, or maybe you mistyped the command. Try using Help->Search R Help for more options.", command->command ().section ('\"', 1, 1)), i18n ("No help found"));
 		}
 	} else {
 		RK_ASSERT (false);
